@@ -1,16 +1,18 @@
 #
-# $Id: YAML.pm,v 0.3 2006/03/22 22:10:28 dankogai Exp $
+# $Id: YAML.pm,v 0.05 2020/08/05 18:26:03 dankogai Exp dankogai $
 #
 package Tie::YAML;
 use strict;
 use warnings;
-our $VERSION = sprintf "%d.%02d", q$Revision: 0.3 $ =~ /(\d+)/g;
+our $VERSION = sprintf "%d.%02d", q$Revision: 0.05 $ =~ /(\d+)/g;
 use base 'Tie::SaveLater';
 use Carp;
 use YAML;
 __PACKAGE__->make_subclasses;
 
-sub load{ 
+sub load{
+    # See https://rt.cpan.org/Public/Bug/Display.html?id=131985
+    local $YAML::LoadBlessed = 1;
     my $class = shift;
     my $filename = shift; 
     open my $fh, "<:raw", $filename or croak "$filename: $!";
